@@ -94,7 +94,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.034';
+our $VERSION = '0.035';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -1075,7 +1075,7 @@ sub _instance {
 
 	my $offset = pop @date || 0;
 	if ( @zone && !$zone[0] ) {
-	    my ( $zulu, $sign, $hr, $min ) = @zone;
+	    my ( undef, $sign, $hr, $min ) = @zone;
 	    $offset -= $sign . ( ( $hr * 60 + ( $min || 0 ) ) * 60 )
 	}
 
@@ -1137,7 +1137,7 @@ Thomas R. Wyant, III (F<wyant at cpan dot org>)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2010, Thomas R. Wyant, III
+Copyright (C) 2005-2011 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
